package com.ruoyi.board.service.impl;

import com.github.yulichang.base.MPJBaseServiceImpl;
import com.ruoyi.board.domain.BoardProtocol;
import com.ruoyi.board.mapper.BoardProtocolMapper;
import com.ruoyi.board.service.IBoardProtocolService;
import com.ruoyi.common.core.domain.TreeSelect;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class BoardProtocolServiceImpl extends MPJBaseServiceImpl<BoardProtocolMapper, BoardProtocol> implements IBoardProtocolService {
    private static final Logger log = LoggerFactory.getLogger(BoardProtocolServiceImpl.class);
    private static final Long DEFAULT_ID = 0L;

    @Override
    public List<TreeSelect> listProtocolTree(BoardProtocol planType) {
        List<BoardProtocol> protocols = list();
        Map<String, List<BoardProtocol>> protocolsByBrand = protocols.stream().collect(Collectors.groupingBy(BoardProtocol::getBrand));
        List<TreeSelect> treeSelects = new ArrayList<>();
        protocolsByBrand.forEach((brand, brandProtocols) -> treeSelects.add(createTreeSelectForBrand(brand, brandProtocols)));
        return treeSelects;
    }

    private TreeSelect createTreeSelectForBrand(String brand, List<BoardProtocol> brandProtocols) {
        TreeSelect treeSelect = new TreeSelect();
        treeSelect.setLabel(brand);
        treeSelect.setId(DEFAULT_ID);
        treeSelect.setChildren(brandProtocols.stream().map(this::mapToTreeSelect).collect(Collectors.toList()));
        return treeSelect;
    }

    private TreeSelect mapToTreeSelect(BoardProtocol protocol) {
        TreeSelect treeSelect = new TreeSelect();
        treeSelect.setId(protocol.getId());
        treeSelect.setLabel(protocol.getProtocol());
        return treeSelect;
    }

    
}
