package com.ruoyi.board.service.impl;

import com.github.yulichang.base.MPJBaseServiceImpl;
import com.ruoyi.board.domain.PlanType;
import com.ruoyi.board.mapper.PlanTypeMapper;
import com.ruoyi.board.service.IPlanTypeService;
import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class PlanTypeServiceImpl extends MPJBaseServiceImpl<PlanTypeMapper, PlanType> implements IPlanTypeService {

    private static final Logger log = LoggerFactory.getLogger(PlanTypeServiceImpl.class);

    @Override
    public List<TreeSelect> listPlanTree(PlanType planType) {
        List<PlanType> list = list();
        List<PlanType> planTypes = buildPlanTree(list);
        return planTypes.stream().map(this::buildTreeSelect).collect(Collectors.toList());
    }

    private TreeSelect buildTreeSelect(PlanType planType){
        List<TreeSelect> childTreeSelectList = planType.getChildren().stream().map(this::buildTreeSelect).collect(Collectors.toList());
        TreeSelect treeSelect = new TreeSelect();
        treeSelect.setId(planType.getId());
        treeSelect.setLabel(planType.getTypeName());
        treeSelect.setChildren(childTreeSelectList);
        return treeSelect;
    }

    private List<PlanType> buildPlanTree(List<PlanType> list) {
        List<PlanType> returnList = new ArrayList<>();
        List<Long> tempList = list.stream().map(PlanType::getId).collect(Collectors.toList());
        for (PlanType planType : list)
        {
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempList.contains(planType.getParentId()))
            {
                recursionFn(list, planType);
                returnList.add(planType);
            }
        }
        if (returnList.isEmpty())
        {
            returnList = list;
        }
        return returnList;

    }

    /**
     * 递归列表
     */
    private void recursionFn(List<PlanType> list, PlanType t)
    {
        // 得到子节点列表
        List<PlanType> childList = getChildList(list, t);
        t.setChildren(childList);
        for (PlanType tChild : childList)
        {
            if (hasChild(list, tChild))
            {
                recursionFn(list, tChild);
            }
        }
    }

    /**
     * 得到子节点列表
     */
    private List<PlanType> getChildList(List<PlanType> list, PlanType t)
    {
        List<PlanType> tlist = new ArrayList<>();
        for (PlanType n : list) {
            if (StringUtils.isNotNull(n.getParentId()) && n.getParentId().longValue() == t.getId().longValue()) {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<PlanType> list, PlanType t)
    {
        return !getChildList(list, t).isEmpty();
    }
}
