package com.ruoyi.board.service.impl;

import com.github.yulichang.base.MPJBaseServiceImpl;
import com.ruoyi.board.domain.RoadGroup;
import com.ruoyi.board.mapper.RoadGroupMapper;
import com.ruoyi.board.service.IRoadGroupService;
import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class RoadGroupServiceImpl extends MPJBaseServiceImpl<RoadGroupMapper, RoadGroup> implements IRoadGroupService {

    @Override
    public List<TreeSelect> listRoadTree(RoadGroup roadGroup) {
        List<RoadGroup> list = list();
        List<RoadGroup> roadGroups = buildRoadTree(list);
        return roadGroups.stream().map(this::buildTreeSelect).collect(Collectors.toList());
    }


    private TreeSelect buildTreeSelect(RoadGroup roadGroup) {
        List<TreeSelect> childTreeSelectList = roadGroup.getChildren().stream().map(this::buildTreeSelect).collect(Collectors.toList());
        TreeSelect treeSelect = new TreeSelect();
        treeSelect.setId(roadGroup.getId());
        treeSelect.setLabel(roadGroup.getRoadName());
        treeSelect.setChildren(childTreeSelectList);
        return treeSelect;
    }

    private List<RoadGroup> buildRoadTree(List<RoadGroup> list) {
        List<RoadGroup> returnList = new ArrayList<>();
        List<Long> tempList = list.stream().map(RoadGroup::getId).collect(Collectors.toList());
        for (RoadGroup roadGroup : list) {
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempList.contains(roadGroup.getParentId())) {
                recursionFn(list, roadGroup);
                returnList.add(roadGroup);
            }
        }
        if (returnList.isEmpty()) {
            returnList = list;
        }
        return returnList;

    }

    /**
     * 递归列表
     */
    private void recursionFn(List<RoadGroup> list, RoadGroup t) {
        // 得到子节点列表
        List<RoadGroup> childList = getChildList(list, t);
        t.setChildren(childList);
        for (RoadGroup tChild : childList) {
            if (hasChild(list, tChild)) {
                recursionFn(list, tChild);
            }
        }
    }

    /**
     * 得到子节点列表
     */
    private List<RoadGroup> getChildList(List<RoadGroup> list, RoadGroup t) {
        List<RoadGroup> tlist = new ArrayList<>();
        for (RoadGroup n : list) {
            if (StringUtils.isNotNull(n.getParentId()) && n.getParentId().longValue() == t.getId().longValue()) {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<RoadGroup> list, RoadGroup t) {
        return !getChildList(list, t).isEmpty();
    }
}
